##  Add Milestones
Milestones are added and managed in the Initiative Fact Sheet type. To add a Milestone, follow the below instructions:
  1. In the Initiative Fact Sheet, hover over the Milestones section, and you will see the + Add button appear.
  2. Click + Add.
  3. Fill Name, Target Date, and Description fields. The Description field is optional, but it is a good practice to fill it out as it offers additional context to other stakeholders involved in the project.
  4. Click Save.
![Adding Milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27414bf57a441014a649f82b03ee4c13_LowRes.gif)
Adding Milestones
